@@ -15,7 +15,6 @@
 
 #include "ldapclient.h"
 
-#include <kldap/ldapobject.h>
 #include <kldap/ldapserver.h>
 #include <kldap/ldapurl.h>
 #include <kldap/ldif.h>
@@ -163,7 +162,7 @@ void LdapClientSearch::Private::readConfig()
         mNoLDAPLookup = true;
     } else {
         for (int j = 0; j < numHosts; ++j) {
-            LdapClient *ldapClient = new LdapClient(j, q);
+            auto *ldapClient = new LdapClient(j, q);
             KLDAP::LdapServer server;
             mClientSearchConfig->readConfig(server, config, j, true);
             if (!server.host().isEmpty()) {
